<?php

namespace FluentFormPro\Components;

use FluentForm\App\Services\FormBuilder\BaseFieldManager;
use FluentForm\Framework\Helpers\ArrayHelper;

class BayarcashFeeField extends BaseFieldManager
{
	public function __construct()
	{
		parent::__construct(
			'bayarcash_fee',
			'Bayarcash Fee',
			['fee', 'payment', 'bayarcash'],
			'payments'
		);

		add_filter('fluentform/payment_field_types', [$this, 'registerAsPaymentField']);
		add_filter('fluent_editor_init_payment_field_types', [$this, 'addFieldIcon']);
	}

	public function registerAsPaymentField($paymentFields)
	{
		$paymentFields[] = $this->key;
		return $paymentFields;
	}

	public function addFieldIcon($paymentFields)
	{
		$paymentFields[$this->key] = [
			'index' => 16,
			'title' => 'Bayarcash Fee',
			'icon' => 'ff-edit-money',
			'settings' => [
				'container_class' => '',
				'label' => 'Bayarcash Fee',
				'admin_field_label' => ''
			]
		];
		return $paymentFields;
	}

	public function getComponent()
	{
		return [
			'index'          => 16,
			'element'        => $this->key,
			'attributes'     => [
				'name'        => $this->key,
				'class'       => 'bayarcash_fee',
				'value'       => '%bc%',
				'type'        => 'text',
				'data-payment_item' => 'yes'
			],
			'settings'      => [
				'container_class'    => '',
				'is_payment_field'   => 'yes',
				'label'             => 'Bayarcash Fee',
				'is_payment_field'  => true
			],
			'editor_options' => [
				'title'      => 'Bayarcash Fee',
				'icon_class' => 'ff-edit-money',
				'template'   => 'inputText'
			]
		];
	}

	public function render($data, $form)
	{
		// Add form ID to the class name
		$data['attributes']['class'] = trim('ff-el-form-control ff-el-payment-field bayarcash_fee bayarcash_fee_' . $form->id);
		$data['attributes']['readonly'] = 'readonly';
		$data['attributes']['value'] = '0.00';

		ob_start();
		?>
        <div class="ff-el-group bayarcash_<?php echo esc_attr($form->id); ?>">
            <span class="ff-el-fee-prefix bc-gateway">Gateway Fee</span>
            <input <?php echo $this->buildAttributes($data['attributes']); ?>>
        </div>
		<?php
		$html = ob_get_clean();
		echo $html;
	}
}

// Initialize the Bayarcash fee field
add_action('fluentform/loaded', function() {
	new BayarcashFeeField();
});