<?php

$slug = FF_BAYARCASH_FSLUG;
function ff_bayarcash_form_fields($form) {
	$form_fields = array(
		array(
			'id'    => 'form-customize-' . $form->id,
			'type'  => 'switcher',
			'title' => sprintf(__('Customization', 'bayarcash-for-fluent-forms')),
			'desc'  => sprintf(__('Form ID: <strong>#%s</strong>. Form Title: <strong>%s</strong>', 'bayarcash-for-fluent-forms'), $form->id, $form->title),
			'help'  => sprintf(__('This to enable customization per form-basis for form: #%s', 'bayarcash-for-fluent-forms'), $form->id),
		),
		array(
			'type'    => 'content',
			'content' => sprintf(__('Get your credentials from %sBayarcash Console Profile%s', 'bayarcash-for-fluent-forms'), '<a href="https://console.bayar.cash/profile" target="_blank">', '</a>'),
			'dependency' => array(['form-customize-' . $form->id, '==', 'true']),
		),
		array(
			'id'      => 'enable-sandbox-' . $form->id,
			'type'    => 'switcher',
			'title'   => __('Enable Sandbox Mode', 'bayarcash-for-fluent-forms'),
			'desc'    => __('Toggle this to switch between sandbox and production environments.', 'bayarcash-for-fluent-forms'),
			'help'    => __('Use sandbox mode to test payments without processing real transactions. Make sure to use sandbox credentials when this is enabled.', 'bayarcash-for-fluent-forms'),
			'dependency' => array(['form-customize-' . $form->id, '==', 'true']),
		),
		array(
			'id'         => 'sandbox-notice-' . $form->id,
			'type'       => 'notice',
			'style'      => 'warning',
			'content'    => __('Sandbox mode is enabled. Make sure to use sandbox credentials for testing.', 'bayarcash-for-fluent-forms'),
			'dependency' => array(['enable-sandbox-' . $form->id, '==', 'true'], ['form-customize-' . $form->id, '==', 'true']),
		),
		array(
			'id'    => 'personal-access-token-' . $form->id,
			'type'  => 'textarea',
			'title' => __('Personal Access Token', 'bayarcash-for-fluent-forms'),
			'desc'  => sprintf(__('Enter your Personal Access Token. Get it from %sBayarcash Console Profile%s', 'bayarcash-for-fluent-forms'), '<a href="https://console.bayar.cash/profile" target="_blank">', '</a>'),
			'help'  => __('Personal Access Token is used to authenticate your requests to the Bayarcash API.', 'bayarcash-for-fluent-forms'),
			'dependency' => array(['form-customize-' . $form->id, '==', 'true']),
		),
		array(
			'id'    => 'portal-key-' . $form->id,
			'type'  => 'text',
			'title' => __('Portal Key', 'bayarcash-for-fluent-forms'),
			'desc'  => sprintf(__('Enter your Portal Key. Get it from %sBayarcash Console Profile%s', 'bayarcash-for-fluent-forms'), '<a href="https://console.bayar.cash/portals" target="_blank">', '</a>'),
			'help'  => __('Portal Key is required for accessing the Bayarcash portal features.', 'bayarcash-for-fluent-forms'),
			'dependency' => array(['form-customize-' . $form->id, '==', 'true']),
		),
		array(
			'id'    => 'api-secret-key-' . $form->id,
			'type'  => 'text',
			'title' => __('API Secret Key', 'bayarcash-for-fluent-forms'),
			'desc'  => sprintf(__('Enter your API Secret Key. Get it from %sBayarcash Console Profile%s', 'bayarcash-for-fluent-forms'), '<a href="https://console.bayar.cash/profile" target="_blank">', '</a>'),
			'help'  => __('API Secret Key is used to secure your API requests to Bayarcash.', 'bayarcash-for-fluent-forms'),
			'dependency' => array(['form-customize-' . $form->id, '==', 'true']),
		),
		array(
			'id'          => 'payment-title-' . $form->id,
			'type'        => 'text',
			'title'       => __('Payment Title', 'bayarcash-for-fluent-forms'),
			'desc'        => __('Enter your Payment Title. Default is <strong>Bayarcash</strong>', 'bayarcash-for-fluent-forms'),
			'help'        => __('This allows you to customize the payment title.', 'bayarcash-for-fluent-forms'),
			'placeholder' => 'Bayarcash',
			'default'     => 'Bayarcash',
			'dependency'  => array(['form-customize-' . $form->id, '==', 'true']),
		),
	);

	return $form_fields;
}

CSF_Setup::createSection($slug, array(
	'id'    => 'form-configuration',
	'title' => __('Form Configuration', 'bayarcash-for-fluent-forms'),
	'icon'  => 'fa fa-gear'
));

$all_forms_query = [];

if (function_exists('wpFluent')) {
	$all_forms_query = wpFluent()->table('fluentform_forms')
	                             ->select(['id', 'title'])
	                             ->orderBy('id')
	                             ->limit(500)
	                             ->get();
}

foreach ($all_forms_query as $form) {
	CSF_Setup::createSection($slug, array(
		'parent'      => 'form-configuration',
		'id'          => 'form-id-' . $form->id,
		'title'       => sprintf(__('Form #%s - %s', 'bayarcash-for-fluent-forms'), $form->id, substr($form->title, 0, 15)),
		'description' => sprintf(__('Configuration for Form #%s - %s', 'bayarcash-for-fluent-forms'), $form->id, $form->title),
		'fields'      => ff_bayarcash_form_fields($form),
	));
}