<?php
$slug = FF_BAYARCASH_FSLUG;

// Simplified payment channel definition
$channel_groups = [
	'malaysia' => [
		'title' => __('Bayarcash Gateway Fee', 'bayarcash-for-fluent-forms'),
		'channels' => [
			'fpx_banking' => __('FPX Online Banking', 'bayarcash-for-fluent-forms'),
			'credit_card' => __('Credit Card', 'bayarcash-for-fluent-forms'),
			'duitnow_banking' => __('DuitNow Online Banking', 'bayarcash-for-fluent-forms'),
			'duitnow_qr' => __('DuitNow QR', 'bayarcash-for-fluent-forms'),
		]
	]
];

function generate_channel_fee_fields($channels) {
	$fields = [];

	foreach ($channels as $channel_key => $channel_label) {
		$base_dependency = ["{$channel_key}_fee_enable", '==', 'true'];

		$fields = array_merge($fields, [
			[
				'id' => "{$channel_key}_fee_enable",
				'type' => 'switcher',
				'title' => sprintf(__('Enable %s Fees', 'bayarcash-for-fluent-forms'), $channel_label),
				'default' => false
			],
			[
				'id' => "{$channel_key}_fee_type",
				'type' => 'select',
				'title' => sprintf(__('%s Fee Type', 'bayarcash-for-fluent-forms'), $channel_label),
				'options' => [
					'flat' => __('Flat Fee Only', 'bayarcash-for-fluent-forms'),
					'percentage' => __('Percentage Only', 'bayarcash-for-fluent-forms'),
					'both' => __('Both Flat + Percentage', 'bayarcash-for-fluent-forms')
				],
				'dependency' => $base_dependency,
				'default' => 'flat'
			],
			[
				'id' => "{$channel_key}_flat_fee",
				'type' => 'number',
				'title' => sprintf(__('%s Flat Fee Amount (RM)', 'bayarcash-for-fluent-forms'), $channel_label),
				'subtitle' => __('Fixed amount to charge', 'bayarcash-for-fluent-forms'),
				'default' => '0',
				'step' => '0.01',
				'dependency' => [
					$base_dependency,
					["{$channel_key}_fee_type", 'any', 'flat,both']
				]
			],
			[
				'id' => "{$channel_key}_percentage_fee",
				'type' => 'number',
				'title' => sprintf(__('%s Percentage Fee', 'bayarcash-for-fluent-forms'), $channel_label) . ' (%)',
				'subtitle' => __('Percentage of transaction amount', 'bayarcash-for-fluent-forms'),
				'default' => '0',
				'step' => '0.01',
				'dependency' => [
					$base_dependency,
					["{$channel_key}_fee_type", 'any', 'percentage,both']
				]
			],
			[
				'id' => "{$channel_key}_fee_description",
				'type' => 'text',
				'title' => sprintf(__('%s Fee Description', 'bayarcash-for-fluent-forms'), $channel_label),
				'subtitle' => __('Description shown to customers', 'bayarcash-for-fluent-forms'),
				'default' => sprintf(__('%s Processing Fee', 'bayarcash-for-fluent-forms'), $channel_label),
				'dependency' => $base_dependency
			],
			[
				'type' => 'submessage',
				'style' => 'info',
				'content' => '<hr style="border-top: 2px solid #eee; margin: 15px 0;">'
			]
		]);
	}

	return $fields;
}

// Create sections for each channel group
foreach ($channel_groups as $group_key => $group_data) {
	CSF_Setup::createSection($slug, [
		'id' => "channel-fees-{$group_key}",
		'title' => $group_data['title'],
		'icon' => 'fa fa-percentage',
		'description' => __('Configure fees for payment channels.', 'bayarcash-for-fluent-forms'),
		'fields' => generate_channel_fee_fields($group_data['channels'])
	]);
}