<?php
use FluentForm\Framework\Helpers\ArrayHelper;

class Bayarcash_Fluent_Forms_Register {
	private static $_instance;

	private $payment_methods;

	public static function get_instance() {
		if (self::$_instance == null) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function __construct() {
		$this->init_payment_methods();
		add_filter('fluentform/available_payment_methods', array($this, 'push'));
	}

	private function init_payment_methods(): void {
		$this->payment_methods = array(
			'fpx_banking'  => __('FPX Online Banking', 'bayarcash-for-fluent-forms'),
			'credit_card'  => __('Credit Card', 'bayarcash-for-fluent-forms'),
			'duitnow_banking' => __('DuitNow Online Banking', 'bayarcash-for-fluent-forms'),
			'duitnow_qr'   => __('DuitNow QR', 'bayarcash-for-fluent-forms'),
			'spaylater'    => __('SPayLater', 'bayarcash-for-fluent-forms'),
			'boost_payflex'=> __('Boost PayFlex', 'bayarcash-for-fluent-forms'),
			'indo_banking' => __('Indonesia Online Banking', 'bayarcash-for-fluent-forms'),
			'indo_ewallet' => __('Indonesia e-Wallet', 'bayarcash-for-fluent-forms'),
			'nets_sg'      => __('NETS Singapore', 'bayarcash-for-fluent-forms')
		);
	}

	public function push($methods) {
		$options = get_option(FF_BAYARCASH_FSLUG);

		foreach ($this->payment_methods as $key => $title) {
			$methods[$key] = [
				'title' => $title,
				'enabled' => 'yes',
				'method_value' => $key,
				'settings' => [
					'option_label' => [
						'type' => 'text',
						'template' => 'inputText',
						'value' => 'Pay with ' . $title,
						'label' => 'Method Label'
					],
				]
			];
		}

		return $methods;
	}
}

Bayarcash_Fluent_Forms_Register::get_instance();